clear
#delimit;
set mem 300m;
set matsize 800;

***merge files from farms***;
local ext = "070210"; *this is the date that corresponds with when the files were delivered*;
***note - after converting .xls files to .dta, store them in 'raw`ext''***;
***create 'proc`ext'' for storing processed files***;

***daily file***;
use raw`ext'/dailywork, clear; 
count;
drop if employee_id == "1";
count;
summ;
tab1 work_crew, m;
gen date = dofc(time_in);
label var date "date of work";
format date %d;
ren break_ break;
sort employee_id date;
save proc`ext'/dailywork, replace;

***employee file***;
use raw`ext'/employee, clear;
count;
drop if employee_id == "1";
count;
summ;
tab1 hire_date gender city zip date_of_birth, m;
drop city zip date_of_birth;
sort employee_id;
save proc`ext'/employee, replace;

***set up job***;
use raw`ext'/job, clear;
count;
drop if job_id == "1";
count;
ren job_ job;
sort job;
save proc`ext'/job, replace;

***piece file***;
use raw`ext'/piece1, clear;
append using raw`ext'/piece2;
count;
drop if employee_id == "1";
count;
summ;
tab1 field_id job, m;
* merge job *;
drop if job == ""; *temporary;
sort job;
merge job using proc`ext'/job, nokeep;
tab _m;
drop _m;
* identify multiple jobs within date *;
gen date = dofc(date_time);
format date %d;
egen jobid = group(job);
egen maxj = max(jobid), by(employee date);
egen minj = min(jobid), by(employee date);
count if maxj ~= minj;
list if maxj ~= minj;
gen flagjobvep = maxj ~= minj;
gen paymentep = 1 if payment_ == "Time & Piece";
replace paymentep = 2 if payment_ == "Time & All Pieces";
replace paymentep = 3 if payment_ == "Piece-Individual";
gen wagesep = pieces*piece_rate if paymentep == 3; *can switch jobs within day;
* collapse to employee-daily file *;
collapse (sum) piecesep=pieces durationep=duration wagesep (max) minpcsep=min_pcs piece_rateep=piece_rate hourly_rateep=hourly_rate paymentep flagjobvep, by(employee date);
replace wagesep = . if payment == 1 | payment == 2;
label var date "date of work";
label var piecesep "total daily number of pieces collected, employee-piece file";
label var durationep "total daily duration of work, employee-piece file";
label var wagesep "total daily wages for piece-individual only (not counting min wage), employee-piece file";
label var minpcsep "minimum pieces for computing time+(all)pieces, employee-piece file";
label var piece_rateep "piece rate, employee-piece file";
label var hourly_rateep "hourly rate, employee-piece file";
label var paymentep "1=time+piece,2=time+all pieces,3=piece-individual, employee-piece file";
label var flagjobvep "flag for multiple jobs within day, employee-piece file";
compress;
sort employee date;
save proc`ext'/piece, replace;

***job-piece file***;
use raw`ext'/jobpiece1, clear;
append using raw`ext'/jobpiece2;
count;
drop if employee_id == "1";
count;
summ;
tab1 field_id job, m;
* merge job *;
drop if job == ""; *temporary;
sort job;
merge job using proc`ext'/job, nokeep;
tab _m;
drop _m;
* identify multiple jobs within date *;
gen date = dofc(date_time);
format date %d;
egen jobid = group(job);
egen maxj = max(jobid), by(employee date);
egen minj = min(jobid), by(employee date);
count if maxj ~= minj;
list if maxj ~= minj;
gen flagjobv = maxj ~= minj;
gen payment = 1 if payment_ == "Time & Piece";
replace payment = 2 if payment_ == "Time & All Pieces";
replace payment = 3 if payment_ == "Piece-Individual";
gen wages = pieces*piece_rate if payment == 3; *can switch jobs within day;
* collapse to employee-daily file *;
collapse (sum) pieces duration wages (max) minpcs=min_pcs piece_rate hourly_rate payment flagjobv, by(employee date);
replace wages = . if payment == 1 | payment == 2;
label var date "date of work";
label var pieces "total daily number of pieces collected, job-piece file";
label var duration "total daily duration of work, job-piece file";
label var wages "total daily wages for piece-individual only (not counting min wage), job-piece file";
label var minpcs "minimum pieces for computing time+(all)pieces, job-piece file";
label var piece_rate "piece rate, job-piece file";
label var hourly_rate "hourly rate, job-piece file";
label var payment "1=time+piece,2=time+all pieces,3=piece-individual, job-piece file";
label var flagjobv "flag for multiple jobs within day, job-piece file";
compress;
sort employee date;
save proc`ext'/jobpiece, replace;

***combine job-piece with piece since some unique to each dataset [asking shlomo]***;
sort employee_id date;
summ pieces duration;
merge employee_id date using proc`ext'/piece;
summ pieces duration;
tab _m;
ren _m mpiecejob;
label var mpiecejob "1=crew (job-piece) only, 2=individual (employee-piece) only, 3=both";
gen dpieces = pieces - piecesep;
label var dpieces "difference in pieces between employee-piece and job-piece file";
list employee_id date pieces piecesep dpieces if pieces ~= piecesep & pieces ~=. & piecesep ~=.;
gen disc = 1 if pieces ~= piecesep & pieces ~=. & piecesep ~=.;
label var disc "discrepancy b/w employee-piece and job-piece";

***merge piece info with daily work and employee chars***;
sort employee_id;
merge employee_id using proc`ext'/employee, nokeep;
tab _m;
drop _m;
sort employee_id date;
merge employee_id date using proc`ext'/dailywork, nokeep;
tab _m;
drop _m;
label var hire_date "date of hire if since 2009";
label var gender "gender of worker";
label var time_in "clock-in time for day";
label var time_out "clock-out time for day";
label var break "minutes of break for day";
label var work_crew "work crew identifier";

***save***;
sort employee_id date;
compress;
save chkm`ext', replace;

