clear
#delimit;
set mem 800m;
set matsize 2800;
set more off;
set seed 123456789;

***prepare data for regressions***;
local fn "prep4reg";
capture log close;
log using `fn'.log, replace;

use mergepw, clear;

***drop outliers***;
drop if hrlywagedc > 20;

***keep main few crops***;
keep if (payment == 2 & piece_rate == .5) | (payment == 1 & piece_rate >= .3 & piece_rate <= .35) | (payment == 1 & piece_rate == 1);

***drop low minpcs***;
drop if payment == 2 & piece_rate == .5 & minpcs < 3;
drop if payment == 1 & piece_rate >= .3 & piece_rate <= .35 & minpcs < 4;
drop if payment == 1 & piece_rate == 1 & minpcs < 3;

***create temp dummies***;
corr temp*sXXXX;
summ tempave6t15_sXXXX, d;
recode tempave6t15_sXXXX (min/65=65) (65/67.5=67.5) (67.5/70=70) (70/72.5=72.5) (72.5/75=75) (75/77.5=77.5) (77.5/80=80) (80/82.5=82.5) (82.5/85=85) (85/87.5=87.5) (87.5/max=90), gen(taveb);
table taveb, c(min tempave6t15_sXXXX max tempave6t15_sXXXX count tempave6t15_sXXXX);
tab taveb, gen(tavebdum);
drop tavebdum1;

***put ozone into 10 ppb units***;
replace ozonemax6t15_sXXXX = ozonemax6t15_sXXXX*100;
replace ozoneave6t15_sXXXX = ozoneave6t15_sXXXX*100;

***create dewpoint dummies - closest station with temp & RH is XXXX***;
* STEP 1: get dewpoint from relative humidity and temp (C);
gen Tf = tempave6t15_sXXXX;
gen RH = rhumave6t15_sXXXX;
gen Tc = 5/9*(Tf-32);
gen X = 1-(0.01*RH);
gen dpc = Tc - (14.55 + 0.114*Tc)*X - ((2.5 + 0.007*Tc)*X)^3 - (15.9 + 0.117*Tc)*X^14;
gen dewpntave6t15_sXXXX = ((9/5)*dpc)+32;
drop Tf RH Tc X dpc;
* STEP 2: create dummies;
summ dewpntave6t15_sXXXX, d;
recode dewpntave6t15_sXXXX (min/45=45) (45/47.5=47.5) (47.5/50=50) (50/52.5=52.5) (52.5/55=55) (55/57.5=57.5) (57.5/60=60) (60/62.5=62.5) (62.5/max=65), gen(dpaveb);
table dpaveb, c(min dewpntave6t15_sXXXX max dewpntave6t15_sXXXX count dewpntave6t15_sXXXX);
tab dpaveb, gen(dpavebdum);
drop dpavebdum1;

***temp-solrad int***;
foreach var of varlist tavebdum2-tavebdum11 {;
	gen srave_`var' = solradave6t15_sXXXX*`var';
};

***crop/piece rate dummies***;
gen double crop = payment*1000 + piece_rate;
qui tab crop, gen(pdum);
drop pdum1;
tab payment, gen(paydum);
drop paydum1;

***dow***;
gen dow = dow(date);
tab dow, gen(dowdum);
drop dowdum1;
capture drop dowdum7;

***trend***;
gen year = year(date);
gen month = month(date);
gen yrm = year*100+month;
tab yrm, gen(yeardum);
drop yeardum1;

***employee in real***;
gen employee = real(substr(employee_id,3,.));

***gender, with some fixes to changing gender (use any reported if conflict w/ unknown, use dominant if conflict across genders (happens 1x))***;
gen male = gender == "Male";
gen female = gender == "Female";
xtsum male female, i(employee);
egen maxm = max(male), by(employee);
egen minm = min(male), by(employee);
egen maxf = max(female), by(employee);
egen minf = min(female), by(employee);
tab employee_id gender if maxm ~= minm | maxf ~= minf;
table employee if maxm ~= minm | maxf ~= minf, c(mean male mean female);
replace male = maxm if maxm ~= minm;
replace female = 0 if maxm ~= minm & female == 1;
replace female = maxf if maxf ~= minf;
table employee if maxm ~= minm | maxf ~= minf, c(mean male mean female);
drop maxm minm maxf minf;
xtsum male female, i(employee);

***drop multiple obs per employee on same date***;
egen maxy = max(hrlypiecedu), by(employee date);
egen miny = min(hrlypiecedu), by(employee date);
gen dy = maxy - miny;
list employee date hrlypiecedu maxy miny dy if dy > 0;
summ hrlypiecedu dy if dy > 0;
drop if employee == 113608 & (date == 18133 | date == 18135 | date == 18136 | date == 18137); *obs don't make sense (look at raw092909/piece & jobpiece 8/24/09-8/28/09);
summ hrlypiecedu dy if dy > 0;
bysort employee date (hrlypiecedu): keep if _n == 1; *rest either don't vary or are off by duration of 1 min (look at raw092909/piece & jobpiece 8/24/09 for duration 330/331);
drop maxy miny dy;

***number of days worked with farm***;
egen totdays = count(hrlypiecedu), by(employee_id);
bysort employee (date): gen ndays = _n;
gen ndays2 = ndays^2;
*tab ndays;

***dep var***;
gen ym = 3 if payment == 2 & piece_rate == .5;
replace ym = 4 if payment == 1 & piece_rate >= .3 & piece_rate <= .35;
replace ym = 3 if payment == 1 & piece_rate == 1;
gen double ystd = (hrlypiecedu-ym)/ysd;

compress;
save `fn', replace;
summ;

set more on;
capture log close;
