clear
#delimit;
set mem 300m;
set matsize 800;
set more off;

***basic regs combining BB & grape data, normalizing by piece rate (interpretation is $ of fruit)***;
local fn "sumstats";
capture log close;
log using `fn'.log, replace;

use prep4reg, clear;

***group covariates***;
local wavevars "tavebdum* apave6t15_sXXXX windsave6t15_sXXXX solradave6t15_sXXXX precave6t15_sXXXX dpavebdum* srave_* pm25ave6t15_sXXXX";
local xcov "dowdum* yeardum* pdum* ndays ndays2 male female";

***use regression sample***;
qui reg ystd ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date);
keep if e(sample);

* SUMMARY STATS *;
***number of dates***;
qui tab date;
disp _result(2);

***number of workers***;
qui tab employee;
disp _result(2);

***days with farm***;
summ ndays;
tab ndays;

***assign pay/piece group & save***;
gen group = 1 if payment == 2 & piece_rate == .5;
replace group = 2 if payment == 1 & piece_rate >= .3 & piece_rate <= .35;
replace group = 3 if payment == 1 & piece_rate == 1;
label define gv 1 "time+all pieces" 2 "time+pieces, $0.3/p" 3 "time+pieces, $1/p";
label values group gv;

***harvest days by group - use for figure 4***;
tab date group;

***summary stats for dep vars***;
summ piece lpiece wage ystd excmind duration;
summ piece lpiece wage ystd excmind duration, d;
bysort group: summ piece lpiece wage ystd excmind duration;
bysort group excmind: summ piece lpiece wage ystd excmind duration;
bysort excmind: summ piece lpiece wage ystd excmind duration;

***summary stats for tenure and gender***;
gen tenurew = ndays/7;
summ male female ndays tenurew;
summ male female ndays tenurew, d;
bysort group: summ male female ndays tenurew;

***w/i and across worker***;
xtsum piece lpiece wage ystd excmind duration, i(employee);
bysort group: xtsum piece lpiece wage ystd excmind duration, i(employee);
bysort group excmind: xtsum piece lpiece wage ystd excmind duration, i(employee);
bysort excmind: xtsum piece lpiece wage ystd excmind duration, i(employee);

***sumstats per crop, 1 obs per date***;
bysort date group: gen ddcc = 1 if _n == 1;
tab ddcc;
bysort group: summ ozone*sXXXX `wavevars' tempave6t15_sXXXX dewpntave6t15_sXXXX if ddcc == 1;

***keep one obs per date***;
egen numw = count(lpiece), by(date);
egen g1 = count(lpiece) if group == 1, by(date);
egen g2 = count(lpiece) if group == 2, by(date);
egen g3 = count(lpiece) if group == 3, by(date);
egen numw_g1 = max(g1), by(date);
egen numw_g2 = max(g2), by(date);
egen numw_g3 = max(g3), by(date);
bysort date: keep if _n == 1;
drop g1 g2 g3;

***summary stats for indep vars***;
corr ozone*sXXXX;
summ ozone*sXXXX;
corr temp*sXXXX;
summ temp*sXXXX;
summ `wavevars' tempave6t15_sXXXX dewpntave6t15_sXXXX;
summ `wmaxvars' tempmax6t15_sXXXX dewpntmax6t15_sXXXX;

******data for figure 4******;
***ozone & temp plots, using all data even if not worked***;
keep date ozoneave6t15_sXXXX tempave6t15_sXXXX solradave6t15_sXXXX numw*;
ren ozone ozone;
ren temp temp;
ren solrad solrad;
gen workday = 1;
sort date;
merge date using ../data/weather09/weat09sum, update keep(tempave6t15_sXXXX solradave6t15_sXXXX);
tab _m;
drop _m;
sort date;
merge date using ../data/poll09/poll09sum, update keep(ozoneave6t15_sXXXX);
tab _m;
drop _m;
sort date;
merge date using ../data/weather10/weat10sum, update keep(tempave6t15_sXXXX solradave6t15_sXXXX);
tab _m;
drop _m;
sort date;
merge date using ../data/poll10/poll10sum, update keep(ozoneave6t15_sXXXX);
tab _m;
drop _m;
compress;
replace ozoneave6t15_sXXXX = ozoneave6t15_sXXXX*1000 if ozoneave6t15_sXXXX < 1;
table date, c(mean ozoneave6t15_sXXXX mean tempave6t15_sXXXX mean solradave6t15_sXXXX max workday mean ozone);
* demeaned *;
gen year = year(date);
gen month = month(date);
keep if month >= 5 & month <= 10;
egen oz09 = mean(ozoneave6t15_sXXXX) if year == 2009;
egen oz10 = mean(ozoneave6t15_sXXXX) if year == 2010;
egen ta09 = mean(tempave6t15_sXXXX) if year == 2009;
egen ta10 = mean(tempave6t15_sXXXX) if year == 2010;
gen ozoneavedm = ozoneave6t15_sXXXX - oz09 if year == 2009;
replace ozoneavedm = ozoneave6t15_sXXXX - oz10 if year == 2010;
gen tempavedm = tempave6t15_sXXXX - ta09 if year == 2009;
replace tempavedm = tempave6t15_sXXXX - ta10 if year == 2010;
table date, c(mean ozoneavedm mean tempavedm max workday);
foreach var of varlist numw_g? {;
	gen any_`var' = 1 if `var' >= 5 & `var' ~= .; *at least 5 people worked on crop;
};
list date ozoneavedm tempavedm any*, sep(0); *figure 4;
list date ozoneavedm tempavedm numw_g1 numw_g2 numw_g3, sep(0); *figure 4;

capture log close;
set more on;
