clear
#delimit;
set mem 1300m;
set matsize 2800;
set more off;

***results for Table 2***;
local fn "table2";
local dv "duration";
capture log close;
log using `fn'.log, replace;

use prep4reg, clear;

***group covariates***;
local wavevars "tavebdum* apave6t15_sXXXX windsave6t15_sXXXX solradave6t15_sXXXX precave6t15_sXXXX dpavebdum* srave_* pm25ave6t15_sXXXX";
local xcov "dowdum* yeardum* pdum* ndays ndays2 male female";

***regs - number of hours worked***;
***setup outeg***;
qui reg `dv' ozoneave6t15_sXXXX;
outreg2 using `fn'.out, replace se text bracket ctitle("setup") nolabel;

***CS - col 3***;
cgmreg `dv' ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date employee);
summ `dv' if e(sample); local pp = r(mean);
outreg2 using `fn'.out, append se text bracket ctitle("`dv' CS") nolabel dec(4) addstat(mdv, `pp');

***FE - col 4***;
areg `dv' ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date) absorb(employee);
summ `dv' if e(sample); local pp = r(mean);
outreg2 using `fn'.out, append se text bracket ctitle("`dv' FE") nolabel dec(4) addstat(mdv, `pp');

* prepare data for employment regression *;
***fill out panel***;
bysort employee date: keep if _n == 1; *remove some duplicates;
tsset employee date;
tsfill;

***days between work***;
egen nwork = count(duration), by(date);
sort employee date;
foreach num of numlist 1/7 {;
	gen ldwl`num' = l`num'.date if l`num'.duration > 0 & l`num'.duration ~= . & l`num'.nwork >= 7;
	gen fdwf`num' = f`num'.date if f`num'.duration > 0 & f`num'.duration ~= . & f`num'.nwork >= 7;
};
egen ldw = rmax(ldwl*);
drop ldwl?;
egen fdw = rmin(fdwf*);
drop fdwf?;
gen gapwdays = fdw-ldw;

***dependent variable (if at least 7 workers that day & < 7 days between work episodes - so actually with farm but choosing not to work)***;
gen work = 1 if duration > 0 & duration ~= . & nwork >= 7;
replace work = 0 if duration == . & nwork >= 7 & gapwdays <= 7;

summ ozoneave6t15_sXXXX;
***remerge covariates to non-working days***;
sort date;
merge date using ../data/weather09/weat09sum, update nokeep;
tab _m;
drop _m;
sort date;
merge date using ../data/poll09/poll09sum, update nokeep;
tab _m;
replace ozonemax6t15_sXXXX = ozonemax6t15_sXXXX*100 if _m == 4;
replace ozoneave6t15_sXXXX = ozoneave6t15_sXXXX*100 if _m == 4;
drop _m;
sort date;
merge date using ../data/weather10/weat10sum, update nokeep;
tab _m;
drop _m;
sort date;
merge date using ../data/poll10/poll10sum, update nokeep;
tab _m;
replace ozonemax6t15_sXXXX = ozonemax6t15_sXXXX*100 if _m == 4;
replace ozoneave6t15_sXXXX = ozoneave6t15_sXXXX*100 if _m == 4;
drop _m;
compress;
summ ozoneave6t15_sXXXX;

***recreate various dummies***;
capture drop taveb*;
recode tempave6t15_sXXXX (min/70=70) (70/72.5=72.5) (72.5/75=75) (75/77.5=77.5) (77.5/80=80) (80/82.5=82.5) (82.5/85=85) (85/87.5=87.5) (87.5/max=90), gen(taveb);
table taveb, c(min tempave6t15_sXXXX max tempave6t15_sXXXX count tempave6t15_sXXXX);
tab taveb, gen(tavebdum);
drop tavebdum1;

***create dewpoint dummies - closest station with temp & RH is XXXX (Visalia airport)***;
capture drop dpaveb* dewpntave6t15_sXXXX;
* STEP 1: get dewpoint from relative humidity and temp (C) (from formula sheet from Alan Barreca's email (abarreca@gmail.com) 8/16/11);
gen Tf = tempave6t15_sXXXX;
gen RH = rhumave6t15_sXXXX;
gen Tc = 5/9*(Tf-32);
gen X = 1-(0.01*RH);
gen dpc = Tc - (14.55 + 0.114*Tc)*X - ((2.5 + 0.007*Tc)*X)^3 - (15.9 + 0.117*Tc)*X^14;
gen dewpntave6t15_sXXXX = ((9/5)*dpc)+32;
drop Tf RH Tc X dpc;
* STEP 2: create dummies;
summ dewpntave6t15_sXXXX, d;
recode dewpntave6t15_sXXXX (min/45=45) (45/47.5=47.5) (47.5/50=50) (50/52.5=52.5) (52.5/55=55) (55/57.5=57.5) (57.5/max=60), gen(dpaveb);
table dpaveb, c(min dewpntave6t15_sXXXX max dewpntave6t15_sXXXX count dewpntave6t15_sXXXX);
tab dpaveb, gen(dpavebdum);
drop dpavebdum1;

***temp-solrad int***;
capture drop srave_*;
foreach var of varlist tavebdum2-tavebdum9 {;
	gen srave_`var' = solradave6t15_sXXXX*`var';
};

***dow***;
drop dow dowdum*;
gen dow = dow(date);
tab dow, gen(dowdum);
drop dowdum1;
capture drop dowdum7;

***trend***;
drop year month yrm yeardum*;
gen year = year(date);
gen month = month(date);
gen yrm = year*100+month;
tab yrm, gen(yeardum);
drop yeardum1;
local xcov "dowdum* yeardum* male female";

***gender***;
egen rmale = max(male), by(employee);
egen rfemale = max(female), by(employee);
drop male female;
ren rmale male;
ren rfemale female;

***regs - worked***;
local dv "work";
	
***CS - col 1***;
cgmreg `dv' ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date employee);
summ `dv' if e(sample); local pp = r(mean);
outreg2 using `fn'.out, append se text bracket ctitle("`dv'") nolabel dec(4) addstat(mdv, `pp');

***FE - col 2***;
areg `dv' ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date) absorb(employee);
summ `dv' if e(sample); local pp = r(mean);
outreg2 using `fn'.out, append se text bracket ctitle("`dv' FE") nolabel dec(4) addstat(mdv, `pp');

capture log close;
set more on;