clear
clear mata
#delimit;
set mem 1300m;
set matsize 2800;
set more off;

***Table 5, col 1-4***;
local fn "table5a";
capture log close;
log using `fn'.log, replace;

use prep4reg, clear;

***tenure interaction***;
replace ndays = ndays/7;
replace ndays2 = ndays^2;
gen ozonetenure = ndays*ozoneave6t15_sXXXX;
gen ozonetenure2 = ndays2*ozoneave6t15_sXXXX;
summ ndays, d;

***gender interaction***;
gen unknown = 1 if male == 0 & female == 0;
replace unknown = 0 if male == 1 | female == 1;
gen ozonefemale = female*ozoneave6t15_sXXXX;
gen ozoneunknown = unknown*ozoneave6t15_sXXXX;

***crop interactions***;
gen crop1 = 1 if crop == 2000.5;
replace crop1 = 0 if crop ~= 2000.5;
gen ozonec1 = crop1*ozoneave6t15_sXXXX;
gen crop2 = 1 if crop >= 1000 & crop < 1001;
replace crop2 = 0 if crop2 == .;
gen ozonec2 = crop2*ozoneave6t15_sXXXX;

***group covariates***;
local wavevars "tavebdum* apave6t15_sXXXX windsave6t15_sXXXX solradave6t15_sXXXX precave6t15_sXXXX dpavebdum* srave_* pm25ave6t15_sXXXX";
local xcov "dowdum* yeardum* pdum* ndays ndays2 female unknown";

***setup outeg***;
qui reg ystd ozoneave6t15_sXXXX ozonetenure ozonetenure2 ozonefemale ozoneunknown ozonec1 ozonec2;
outreg2 using `fn'_ols_ave.out, replace se text bracket ctitle("setup") nolabel;

***col 1, baseline***;
cgmreg ystd ozoneave6t15_sXXXX `wavevars' `xcov', cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ols_ave.out, append se text bracket ctitle("baseline") nolabel bdec(3) addstat(mdv, `pp');

***col 2, ozone*tenure2***;
cgmreg ystd ozoneave6t15_sXXXX ozonetenure ozonetenure2 `wavevars' `xcov' ndays ndays2, cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ols_ave.out, append se text bracket ctitle("tenure2") nolabel bdec(3) addstat(mdv, `pp');

***col 3, ozone*gender***;
cgmreg ystd ozoneave6t15_sXXXX ozonefemale ozoneunknown female unknown `wavevars' `xcov', cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ols_ave.out, append se text bracket ctitle("gender") nolabel bdec(3) addstat(mdv, `pp');

***col 4, ozone*crop***;
cgmreg ystd ozoneave6t15_sXXXX ozonec1 ozonec2 `wavevars' `xcov', cluster(date employee);
summ ystd if e(sample); local pp = r(mean);
outreg2 using `fn'_ols_ave.out, append se text bracket ctitle("crop") nolabel bdec(3) addstat(mdv, `pp');

capture log close;
set more on;