clear
#delimit;
set mem 300m;

***daily summary measures for weather data closest to Lagomarsino***;
capture log close;
log using weat09sum.log, replace;

use weat09, clear;
capture destring site, replace;

***keep certain monitors***;
keep if site == XXXX | site == YYYY;

***rename quality vars & assign label***;
for var quality_WINSPDd quality_WINSPDs quality_TEMP quality_SORAD quality_PRECIP quality_BPSTA quality_DEWPNT quality_RELHUM \ 
	new qwindd qwinds qtemp qsolrad qprec qap qdewpnt qrhum: ren X Y;

***keep only valid observations***;
tab1 q*, nol m;
foreach var of varlist temp solrad prec ap dewpnt rhum winds windd {;
	tabstat `var', by(q`var') s(mean count) missing;
};
summ temp solrad prec ap dewpnt rhum winds windd;
for var qtemp qsolrad qprec qap qdewpnt qrhum qwinds qwindd \ var temp solrad prec ap dewpnt rhum winds windd: replace Y = . if (X ~= 0 & X ~= . & X ~= -9) & Y ~= .;
summ temp solrad prec ap dewpnt rhum winds windd;
drop q*;

***compute daily measure for ave day (6-3)***;
keep if hour >= 6 & hour <= 15;
foreach var of varlist temp solrad prec ap winds windd dewpnt rhum {;
	egen `var'max6t15_s = max(`var'), by(site date);
	egen `var'min6t15_s = min(`var'), by(site date);
	egen `var'ave6t15_s = mean(`var'), by(site date);
};

***keep 1 obs per date***;
sort site date tempmax6t15_s;
by site date: keep if _n == 1;
drop hour temp solrad prec ap dewpnt rhum winds windd aday;

***reshape***;
capture drop name;
drop prelim* minute* obs*;
reshape wide temp* prec* winds* windd* ap* solrad* dewpnt* rhum* dist*, i(date) j(site);

***drop if completely missing***;
foreach var of varlist temp* prec* winds* windd* ap* solrad* dewpnt* rhum* {;
	summ `var';
	if r(N) == 0 {;
		drop `var';
	};
};

***final cleaning***;
compress;
sort date;
save weat09sum, replace;

capture log close;
