clear
#delimit;
set mem 300m;

***read in weather data & merge into one file***;
capture log close;
log using weat10.log, replace;

***read in each element - RENAME AS APPROPRIATE in the insheet line (line 16)***;
***NOTE: data was downloaded monthly, make adjustments in 'numlist' below as appropriate***;
local pn "TEMP SORAD PRECIP DEWPNT RELHUM BPSTA";
foreach var1 of local pn {;
	
	foreach m of numlist 1/12 {;
	
		insheet using raw/`var1'_m`m'.csv, comma clear names;
		drop in -9/l;
		foreach var of varlist variable units met_source flag {;
			tab `var', m;
			drop `var';
		};
		drop name latitude longitude monitoring_id;
		gen datev = date(date, "ymd");
		drop date;
		ren datev date;
		format date %d;
		ren start hour;
		ren value `var1';
		replace `var1' = . if `var1' < 0; *all temps < 0 seem invalid;
		ren quality quality_`var1';
		ren prelim prelim_`var1';
		ren obs_type obs_type_`var1';
		ren minutes minutes_`var1';
		replace quality = -9 if quality == .;
		sort site date hour;
		compress;
		save `var1'`m', replace;
	
	};
	
};

***wind speed - two values***;
local pn "WINSPD";
foreach var1 of local pn {;
	
	foreach m of numlist 1/12 {;
	
		insheet using raw/`var1'_m`m'.csv, comma clear names;
		drop in -9/l;
		foreach var of varlist variable units met_source flag {;
			tab `var', m;
			drop `var';
		};
		drop name latitude longitude monitoring_id;
		gen datev = date(date, "ymd");
		drop date;
		ren datev date;
		format date %d;
		ren start hour;
		ren ws `var1's;
		ren wd `var1'd;
		ren quality_ws quality_`var1's;
		ren quality_wd quality_`var1'd;
		ren prelim prelim_`var1';
		ren obs_type obs_type_`var1';
		ren minutes minutes_`var1';
		replace quality_`var1's = -9 if quality_`var1's == .;
		replace quality_`var1'd = -9 if quality_`var1'd == .;
		sort site date hour;
		compress;
		save `var1'`m', replace;
	
	};
	
};

***append into year***;
local pn "WINSPD TEMP SORAD PRECIP DEWPNT RELHUM BPSTA";
foreach var1 of local pn {;
	use `var1'1, clear;
	foreach m of numlist 2/12 {;
		append using `var1'`m';
		erase `var1'`m'.dta;
	};
	compress;
	sort site date hour;
	save `var1', replace;
	erase `var1'1.dta;
};

***clean duplicate obs***;
local pn "TEMP PRECIP DEWPNT RELHUM";
foreach var1 of local pn {;
	use `var1', clear;
	collapse (mean) `var1' minutes (max) quality, by(site date hour);
	save `var1', replace;
};

***merge elements***;
local pn "TEMP SORAD PRECIP BPSTA DEWPNT RELHUM";
use WINSPD, clear;
foreach var1 of local pn {;
	sort site date hour;
	merge site date hour using `var1';
	tab _m;
	drop _m;
	erase `var1'.dta;
};
erase WINSPD.dta;

***deal with duplicates***;
gen double iid = date*10000000+ site*100 + hour;
xtsum WINSPD* TEMP SORAD DEWPNT RELHUM PRECIP BPSTA, i(iid);
duplicates tag site date hour, gen(mid);
tab site if mid >= 1;
bysort site date hour: keep if _n == 1;
drop iid mid;
isid site date hour;

***final cleaning***;
order site date hour;
ren BPSTA ap;
ren PRECIP prec;
ren DEWPNT dewpnt;
ren RELHUM rhum;
ren SORAD solrad;
ren TEMP temp;
ren WINSPDd windd;
ren WINSPDs winds;
label var dewpnt "dew point (F)";
label var rhum "relative humidity (%)";
label var windd "resultant wind direction (degrees)";
label var winds "resultant wind speed (mph)";
label var temp "temperature (F)";
label var ap "atmospheric pressure (millibars)";
label var prec "precipitation (mm)";
label var solrad "solar radiation (Watts/m2)";

***quality label***;
label define qual 0 "valid observation" 1 "the data supplier marked the observation as suspect, but it is still valid" 
	2 "the automated qa routine judged the observation questionable and invalid" 3 "the automated qa routine judged the 
	observation invalid" 4 "the data supplier flagged the observation invalid" 5 "the observation was flagged invalid 
	manually" -9 "no quality code reported";
local pn "WINSPDs WINSPDd TEMP SORAD DEWPNT RELHUM PRECIP BPSTA";
foreach var1 of local pn {;
	label values quality_`var1' qual;
};

***drop if no data***;
egen nobs = rmiss(temp prec solrad ap dewpnt rhum windd winds);
tab nobs;
drop if nobs == 8;
drop nobs;

compress;
sort site date hour;
save weat10, replace;

capture log close;

